==> kylin-scanner_3.2.0.4.orig.tar.gz: kylin-scanner-3.2.0.4/src/thumbnailwidget.h <==
#ifndef THUMBNAILWIDGET_H
#define THUMBNAILWIDGET_H

#include "thumbnaildelegate.h"
#include "globalsignal.h"
#include "saneobject.h"
#include "include/common.h"
#include "../codec/kylinimagecodec/kylinimagecodec.h"

#include <QWidget>
#include <QListView>
#include <QStandardItem>
#include <QStandardItemModel>
#include <QListWidget>
#include <QListWidgetItem>
#include <QListData>
#include <QListIterator>
#include <QSize>
#include <QImage>
#include <QPixmap>
#include <QIcon>
#include <QGraphicsDropShadowEffect>
#include <QScrollBar>
#include <QFile>
#include <QFileInfo>
#include <QPaintEvent>
#include <QPainter>
#include <QStyleOption>
#include <QStyle>

#include <opencv4/opencv2/core.hpp>
#include <opencv4/opencv2/imgcodecs.hpp>
#include <opencv4/opencv2/imgproc.hpp>
using namespace cv;


class ScanStandardItem: public QStandardItem
{
public:
    void setPath(const QString &path);
    QString getPath();

    int getRowCountLocation() const;
    void setRowCountLocation(int value);

private:
    QString m_path;
    int rowCountLocation;
};

class ThumbnailWidget : public QListView
{
    Q_OBJECT
public:
    explicit ThumbnailWidget(QWidget *parent = nullptr);

    static int scanPictureCount;

    void setupGui();
    void initConnect();
    void initSettings();


protected:
        void paintEvent(QPaintEvent *event) override;


private:
    ThumbnailDelegate *m_thumbnailDelegate;
    QStandardItemModel *m_thumbnailItemModel;

signals:

public slots:
    void showThumbnailIcon();

    void showNormalImageAfterScan();

    void clickedItemSlot(const QModelIndex &index);

};

#endif // THUMBNAILWIDGET_H

==> kylin-scanner_3.2.0.6.tar.gz: kylin-scanner-3.2.0.6/src/thumbnailwidget.h <==
#ifndef THUMBNAILWIDGET_H
#define THUMBNAILWIDGET_H

#include "thumbnaildelegate.h"
#include "globalsignal.h"
#include "saneobject.h"
#include "include/common.h"
#include "../codec/kylinimagecodec/kylinimagecodec.h"

#include <QWidget>
#include <QListView>
#include <QStandardItem>
#include <QStandardItemModel>
#include <QListWidget>
#include <QListWidgetItem>
#include <QListData>
#include <QListIterator>
#include <QSize>
#include <QImage>
#include <QPixmap>
#include <QIcon>
#include <QGraphicsDropShadowEffect>
#include <QScrollBar>
#include <QFile>
#include <QFileInfo>
#include <QPaintEvent>
#include <QPainter>
#include <QStyleOption>
#include <QStyle>

#include <opencv4/opencv2/core.hpp>
#include <opencv4/opencv2/imgcodecs.hpp>
#include <opencv4/opencv2/imgproc.hpp>
using namespace cv;


class ScanStandardItem: public QStandardItem
{
public:
    void setPath(const QString &path);
    QString getPath();

    int getRowCountLocation() const;
    void setRowCountLocation(int value);

private:
    QString m_path;
    int rowCountLocation;

};

class ThumbnailWidget : public QListView
{
    Q_OBJECT
public:
    explicit ThumbnailWidget(QWidget *parent = nullptr);

    static int scanPictureCount;

    void setupGui();
    void initConnect();
    void initSettings();
    void themeChange();
    bool isDarkTheme();


protected:
//        void paintEvent(QPaintEvent *event) override;


private:
    ThumbnailDelegate *m_thumbnailDelegate;
    QStandardItemModel *m_thumbnailItemModel;

signals:

public slots:
    void showThumbnailIcon();

    void showNormalImageAfterScan();

    void clickedItemSlot(const QModelIndex &index);

};

#endif // THUMBNAILWIDGET_H
